@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: MetaObject
-version: 0.0.6
-id: MetaObject-0.0.6-50acdf1ddb6e73d58b1ad9478134d312
+version: 0.0.6.20110925
+id: MetaObject-0.0.6.20110925-5cb3b0cbe70afd6d30d84c90e07e6e97
 
 license: BSD3
 copyright: 2006 Caio Marcelo, 2008 Audrey Tang
@@ -9,6 +9,7 @@ maintainer: Audrey Tang <audreyt@audreyt.org>
 stability: experimental
 homepage:
 package-url:
+synopsis: A meta-object system for Haskell based on Perl 6
 description: A meta-object system for Haskell based on Perl 6
 category: Development, Pugs
 author: Audrey Tang <audreyt@audreyt.org>
@@ -17,22 +18,22 @@ exposed: True
 exposed-modules: MO.Base MO.Compile.Attribute MO.Compile.Class
                  MO.Compile.Role MO.Compile MO.Run MO.Util MO.Capture MO.Util.C3
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/MetaObject-0.0.6
-library-dirs: /usr/local/lib/ghc/MetaObject-0.0.6
-hs-libraries: HSMetaObject-0.0.6
+trusted: False
+import-dirs: /usr/local/lib/ghc/MetaObject-0.0.6.20110925
+library-dirs: /usr/local/lib/ghc/MetaObject-0.0.6.20110925
+hs-libraries: HSMetaObject-0.0.6.20110925
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
-         containers-0.4.0.0-f1307d32d8f4b51a1487c01f0997b6d9
-         haskell98-1.1.0.1-3ce559675b118e85a39def472ca9857c
-         stringtable-atom-0.0.6.1-a6b5270b13200ab10bb177d1f7b12685
+depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
+         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
+         stringtable-atom-0.0.6.1-3f9c00d6948d117456dbe61600887954
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-MetaObject-0.0.6/html/MetaObject.haddock
-haddock-html: /usr/local/share/doc/hs-MetaObject-0.0.6/html
+haddock-interfaces: /usr/local/share/doc/hs-MetaObject-0.0.6.20110925/html/MetaObject.haddock
+haddock-html: /usr/local/share/doc/hs-MetaObject-0.0.6.20110925/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
